@@ -1,4 +1,4 @@
-package Devel::Trace::Subs 0.16;
+package Devel::Trace::Subs 0.17;
 use 5.012;
 use strict;
 use warnings;
@@ -379,6 +379,12 @@ bug as I make changes.
 
 L<https://github.com/stevieb9/devel-trace-subs>
 
+=head1 BUILD REPORTS
+
+Travis-CI: L<https://travis-ci.org/stevieb9/devel-trace-subs>
+
+CPAN Testers: L<http://matrix.cpantesters.org/?dist=Devel-Trace-Subs>
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
